==> apache-cloudstack-4.15.2.0-src.tar.bz2: apache-cloudstack-4.15.2.0-src/plugins/network-elements/bigswitch/src/main/java/com/cloud/agent/api/GetControllerDataAnswer.java <==
//
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
//

package com.cloud.agent.api;

public class GetControllerDataAnswer extends Answer {
    private final String _ipAddress;
    private final boolean _isMaster;

    public GetControllerDataAnswer(final GetControllerDataCommand cmd,
            final String ipAddress, final boolean isMaster){
        super(cmd);
        this._ipAddress = ipAddress;
        this._isMaster = isMaster;
    }

    public GetControllerDataAnswer(final Command command, final Exception e) {
        super(command, e);
        this._ipAddress = null;
        this._isMaster = false;
    }

    public String getIpAddress() {
        return _ipAddress;
    }

    public boolean isMaster() {
        return _isMaster;
    }
}

==> apache-cloudstack-4.22.0.0-src.tar.bz2: apache-cloudstack-4.22.0.0-src/plugins/network-elements/bigswitch/src/main/java/com/cloud/agent/api/GetControllerDataAnswer.java <==
//
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
//

package com.cloud.agent.api;

public class GetControllerDataAnswer extends Answer {
    private final String _ipAddress;
    private final boolean _isPrimary;

    public GetControllerDataAnswer(final GetControllerDataCommand cmd,
            final String ipAddress, final boolean isPrimary){
        super(cmd);
        this._ipAddress = ipAddress;
        this._isPrimary = isPrimary;
    }

    public GetControllerDataAnswer(final Command command, final Exception e) {
        super(command, e);
        this._ipAddress = null;
        this._isPrimary = false;
    }

    public String getIpAddress() {
        return _ipAddress;
    }

    public boolean isPrimary() {
        return _isPrimary;
    }
}
